/**********************************************************************************************/
/* Replication files for                                                                      */
/* Jessen, Robin, Rostam-Afschar, Davud, and Schmitz, Sebastian                               */
/* "How Important is Precautionary Labor Supply?" (2016)                                      */
/* run.do                                                                                     */
/* Program files: run.do: Do-file containing Stata code to reproduce the results              */
/* in the paper's tables and figures based on data from the German Socio-Economic Panel (SOEP)*/
/* and the microsimulation model STSM, see Jessen et al. (2015) and Steiner et al. (2012).    */
/* This program was written to run in Stata version 13.1.                                     */
/*                                                                                            */
/* run.do calls data_processing.do, and sample_restriction.do                                 */
/* sample_restriction.do calls risk_measures.do                                               */
/*                                                                                            */
/* - run.do returns estimation results, and figures                                           */
/* - data_processing.do retrieves, merges, generates, and labels data directly from           */
/*   SOEP wide, long, and STSM, returns raw_data.dta                                          */
/* - sample_restriction.do restricts the data to the estimation sample, returns estimation.dta*/
/* - risk_measures.do generates risk measures                                                 */
/*                                                                                            */
/* Data files required:                                                                       */
/* - SOEP version 30 long, available at http://www.diw.de/en/soep                             */
/* - SOEP version 30 wide, available at http://www.diw.de/en/soep                             */
/* - SOEP spatial planning regions (geocodes), municipal size classes for STSM                */
/* - Net incomes from STSM, on-site access available on request  to the authors               */
/* Details about the data are described in the data section of the paper.                     */
/*                                                                                            */
/* Use of these files is permitted under the following condition:                             */
/* Anyone using these files must include a citation of the paper in his or her work.          */
/**********************************************************************************************/

/* Begin: Stata setup */
set more off
set trace off
set type double, permanently
set scheme s1color, permanently
set varabbrev off
macro drop _all
scalar drop _all
cap log close

	global SOEP_LONG_PATH   "H:\SOEP\SOEP30\stata_de+en_v30l\"
	global SOEP_WIDE_PATH   "H:\SOEP\SOEP30\stata_de+en_v30\"
	global STSM_PATH        "H:\Neuer_Ordner\stsm\"
	global TABLES           "H:\hours\" 
	global FIGURES          "H:\hours\"  
	global LOG_PATH         "H:\hours\"  
	global GEOCODES_PATH    "H:\SOEP\SOEP30\SOEP_Geocodes\"
	global DATA_PATH        "H:\hours\"  
	global DO_PATH          "H:\repfiles2016_11_14\" 
	sysdir set PLUS H:\ado\plus
	sysdir set PERSONAL H:\ado\personal
	cd "$DO_PATH"

local sysdate = c(current_date)
local systime = c(current_time)
log using "${LOG_PATH}analysis_`sysdate'", smcl replace
/* End: Stata setup */

/* Begin: Data availability setup */
    global NETWAGES "0" /* 1: add net wages (needs access to microsimulation model), 0: do not*/
	global REGIONAL "0" /* 1: add regional data from SOEP, 0: do not*/
	global FIRSTYEAR "2000" /*First year of analysis*/
	global LASTYEAR "2012" /*Last year of analysis*/
/* End: Data availability setup */

/* Begin: Program options */
	global DATA_PROCESSING "0"   /* 1: Run data_processing; 0: file if raw_data.dta was already saved */
	global SAMPLE_RESTRICTION "0" /* 1: Run Sample restriction; 0: file if estimation.dta was already saved */
	global WAGERISK "1" /*1: Generate wage risk measures following Parker et al 2005, Fossen and Rostam-Afschar (2013), and subjective risk measures. Generate expected probability of unemployment. */
	global ESTIMATION "0" /* 1: Estimate dynamic labor supply equations */
	global GRAPHS "1" /* Generate graphs, if 1 and ESTIMATION is 1, graph of simulation will be generated */
/* End: Program options */

/* Begin: Modelling options */
	global l "l" /* 1: logs, "": levels for risk measures */
	global DETRENDWAGE "1" /* 1: Detrend wages for construction of Parker et al.'s uncertainty measure */	
	global DETREND_VARS "c.age c.age2 i.mediumeduc c.age#i.mediumeduc c.age2#i.mediumeduc higheduc c.age#i.higheduc c.age2#i.higheduc"
	global DEPVAR "paid_hours" /* paid hours */
/* End: Modelling options */

/*Estimation Options*/
	global MAINOCC "All"	
	global MAINOPT "robust artests(2)" /* System GMM, twostep "robust artests(2) twostep"  "robust artests(2) twostep" */
	global TESTS "AR1inFD AR2inFD Hansen" /* "AR1inFD AR2inFD Sargan Hansen" */
	global CONTROLS "i.year pgbilzt experience east youngkid midkid oldkid age age2 famstat1 famstat2 i.psample"
	global MAINIV "gmm(l.l${DEPVAR}, collapse)  iv(${CONTROLS} uncertainty expunemployed  l.lab_inc)" /* iv(${CONTROLS} uncertainty expunemployed) */
	global OVERTIMEDEPVAR "dovertime_paid" /* dovertime [or] dovertime_paid */
	global TWOSLS "(wage = l.lab_inc)"
	global FDIV   "(d.wage  = dl.lab_inc)"
	global AHsiao "(ld.l${DEPVAR} d.wage = l2.l${DEPVAR} dl.lab_inc)"
	global ALTDEPVARS " e11101 pgtatzt pgvebzt plb0241 "  /* pgtatzt e11101 pgvebzt plb0241 */ 
	global DEPVARS "${DEPVAR} ${ALTDEPVARS}" /* For risk measure construction */ 
	
if ${DATA_PROCESSING}==1 {	
	do "${DO_PATH}data_processing"
}
if ${SAMPLE_RESTRICTION}==1 {
	do "${DO_PATH}sample_restriction"
}
if ${ESTIMATION}==1{
use "${DATA_PATH}estimation", clear

/***********************************************************/
/*              Table: Summary Statistics                  */ 
/***********************************************************/
local options ${MAINOPT}
local instruments ${MAINIV} 

if ${NETWAGES}==1{
replace lab_inc=pglabnet
replace wage=lnet_wage_${DEPVAR}
replace uncertainty=sd${l}_net_wage_${DEPVAR}
}

foreach var of varlist $OVERTIMEDEPVAR dependent selfemployed  bluecollar whitecollar civilservant expunemployed_BU east isco_1-isco_9 youngkid midkid oldkid{
	replace `var'=`var'*100
}

# d;
if ${NETWAGES}==1{;
sutex ${DEPVAR} ${OVERTIMEDEPVAR} /* Depvars */
whr_${DEPVAR} net_wage_${DEPVAR}  pglabgro pglabnet savings
[aw=phrf] if olssample==1, file("${TABLES}\sumstats.tex") replace minmax digits(2) labels;
sutex sd${l}_whr_${DEPVAR}_BU   sd${l}_net_wage_${DEPVAR}_BU  
[aw=phrf] if olssample==1, file("${TABLES}\sumstats.tex")  append minmax digits(3) labels;
sutex expunemployed_BU age pgbilzt experience youngkid midkid oldkid east  selfemployed  bluecollar whitecollar civilservant isco_1-isco_9
[aw=phrf] if olssample==1, file("${TABLES}\sumstats.tex")  append minmax digits(1) labels;
};
#d cr

foreach var of varlist $OVERTIMEDEPVAR  dependent selfemployed  bluecollar whitecollar civilservant expunemployed_BU east isco_1-isco_9 youngkid midkid oldkid{
	replace `var'=`var'/100
}
		
/***********************************************************/
/*     Table: Compare Different Specifications             */		
/***********************************************************/
local options ${MAINOPT}
local instruments ${MAINIV} 

replace lab_inc=pglabgro
replace wage=lwhr_${DEPVAR}
replace uncertainty=sd${l}_whr_${DEPVAR}

/* Pooled OLS, no instruments */
eststo OLS_gross: xi: reg l${DEPVAR} uncertainty expunemployed  wage ${CONTROLS} [aw=phrf] if ${MAINOCC} ==1 & olssample==1 , vce(cluster pid)
local static_g `static_g' OLS_gross

/* Pooled OLS, instruments */
eststo OLSIV_gross: xi: ivregress 2sls l${DEPVAR} uncertainty expunemployed ${TWOSLS} ${CONTROLS} [aw=phrf] if ${MAINOCC} ==1 & olssample==1, vce(cluster pid)
local static_g `static_g' OLSIV_gross

/* FD-IV, instrumented wages */
eststo IVFD_gross: xi: ivregress 2sls d.l${DEPVAR} d.uncertainty d.expunemployed ${FDIV} D.(${CONTROLS}) if ${MAINOCC} ==1 & olssample==1 , vce(cluster pid)
local static_g `static_g' IVFD_gross

/* Anderson-Hsiao with instrumented wages and income */
eststo AH_gross: xi: ivregress 2sls	d.l${DEPVAR} ${AHsiao} d.uncertainty d.expunemployed D.(${CONTROLS}) if ${MAINOCC} ==1 & olssample==1, vce(cluster pid)
local dynamic_g `dynamic_g' AH_gross

/* Difference GMM */
# d;
mata: mata mlib index; 
eststo DGMM_gross: xi: xtabond2 l${DEPVAR} l.l${DEPVAR} uncertainty expunemployed wage  ${CONTROLS}
 if ${MAINOCC} ==1, `instruments' `options' nolevel;
#d cr
local dynamic_g `dynamic_g' DGMM_gross
mat b =  e(gmmlaglimits)
estadd scalar lagstart = b[1,1]
estadd scalar lagend = b[2,1]
estadd scalar AR1inFD = e(ar1p)
estadd scalar AR2inFD = e(ar2p)
estadd scalar Sargan =  e(sarganp)
estadd scalar Hansen =  e(hansenp)

/* System GMM */
# d;
eststo SGMM_gross: xi: xtabond2 l${DEPVAR} l.l${DEPVAR} uncertainty expunemployed wage ${CONTROLS}
if ${MAINOCC} ==1 & olssample==1, `instruments' `options';
#d cr
local dynamic_g `dynamic_g' SGMM_gross
mat b =  e(gmmlaglimits)
estadd scalar lagstart = b[1,1]
estadd scalar lagend = b[2,1]
estadd scalar AR1inFD = e(ar1p)
estadd scalar AR2inFD = e(ar2p)
estadd scalar Sargan =  e(sarganp)
estadd scalar Hansen =  e(hansenp)

esttab `static_g' using "${TABLES}\static_gross.tex",  label se(3) b(3) replace mtitles(`static_g')  scalars(${TESTS}) star(* 0.10 ** 0.05 *** 0.01) 
esttab `dynamic_g' using "${TABLES}\dynamic_gross.tex",  label se(3) b(3) replace mtitles(`dynamic_g')  scalars(${TESTS}) star(* 0.10 ** 0.05 *** 0.01) 
esttab `static_g' `dynamic_g' using "${TABLES}\comparison_gross.tex",  label se(3) b(3) replace mtitles(`static_g' `dynamic_g')  scalars(${TESTS}) star(* 0.10 ** 0.05 *** 0.01) 
local static_g
local dynamic_g
		
if ${NETWAGES}==1{
	replace lab_inc=pglabnet
	replace wage=lnet_wage_${DEPVAR}
	replace uncertainty=sd${l}_net_wage_${DEPVAR}	

	/* Pooled OLS, no instruments */
	eststo OLS_net: xi: reg l${DEPVAR} uncertainty expunemployed  wage ${CONTROLS} [aw=phrf] if ${MAINOCC} ==1 & olssample==1, vce(cluster pid)
	local static_n `static_n' OLS_net
	
	/* Pooled OLS, instruments */
	eststo OLSIV_net: xi: ivregress 2sls l${DEPVAR} uncertainty expunemployed ${TWOSLS} ${CONTROLS} [aw=phrf] if ${MAINOCC} ==1 & olssample==1, vce(cluster pid)
	local static_n `static_n' OLSIV_net
	
	/* FD-IV, instrumented wages */
	eststo IVFD_net: xi: ivregress 2sls d.l${DEPVAR} d.uncertainty d.expunemployed ${FDIV} D.(${CONTROLS}) if ${MAINOCC} ==1 & olssample==1 , vce(cluster pid)
	local static_n `static_n' IVFD_net
	
	/* Anderson-Hsiao with instrumented wages and income */
	eststo AH_net: xi: ivregress 2sls	d.l${DEPVAR} ${AHsiao} d.uncertainty d.expunemployed D.(${CONTROLS}) if ${MAINOCC} ==1 & olssample==1, vce(cluster pid)
	local dynamic_n `dynamic_n' AH_net

	/* Difference GMM */
	# d;
	eststo DGMM_net: xi: xtabond2 l${DEPVAR} l.l${DEPVAR} uncertainty expunemployed wage ${CONTROLS} 
	if ${MAINOCC} ==1, `instruments' `options' nolevel; 
	#d cr
	local dynamic_n `dynamic_n' DGMM_net
	mat b =  e(gmmlaglimits)
	estadd scalar lagstart = b[1,1]
	estadd scalar lagend = b[2,1]
	estadd scalar AR1inFD = e(ar1p)
	estadd scalar AR2inFD = e(ar2p)
	estadd scalar Sargan =  e(sarganp)
	estadd scalar Hansen =  e(hansenp)

	/* System GMM */
	# d;
	eststo SGMM_net: xi: xtabond2 l${DEPVAR} l.l${DEPVAR} uncertainty expunemployed wage ${CONTROLS} 
	if ${MAINOCC} ==1 & olssample==1, `instruments' `options';
	#d cr
	local dynamic_n `dynamic_n' SGMM_net
	mat b =  e(gmmlaglimits)
	estadd scalar lagstart = b[1,1]
	estadd scalar lagend = b[2,1]
	estadd scalar AR1inFD = e(ar1p)
	estadd scalar AR2inFD = e(ar2p)
	estadd scalar Sargan =  e(sarganp)
	estadd scalar Hansen =  e(hansenp)
	
	esttab `static_n' using "${TABLES}\static_net.tex",  label se(3) b(3) replace mtitles(`static_n')  scalars(${TESTS}) star(* 0.10 ** 0.05 *** 0.01) 
	esttab `dynamic_n' using "${TABLES}\dynamic_net.tex",  label se(3) b(3) replace mtitles(`dynamic_n')  scalars(${TESTS}) star(* 0.10 ** 0.05 *** 0.01) 
	esttab `static_n' `dynamic_n' using "${TABLES}\comparison_net.tex",  label se(3) b(3) replace mtitles(`static_n' `dynamic_n')  scalars(${TESTS}) star(* 0.10 ** 0.05 *** 0.01) 
	local static_n
	local dynamic_n
}		

/***********************************************************/
/*              Simulation (Graph & Table)                 */		
/***********************************************************/
if ${NETWAGES}==1{
	estimates restore SGMM_net
}
else {
	estimates restore SGMM_gross
}
/* Simulation in levels */
replace uncertainty=sd${l}_whr_${DEPVAR}
su uncertainty if ${MAINOCC}==1, d
gen ${DEPVAR}_SRmin = exp(l${DEPVAR} - _b[uncertainty]*(uncertainty-r(min)))
gen ${DEPVAR}_LRmin = exp(l${DEPVAR} - _b[uncertainty]/(1-_b[l.l${DEPVAR}])*(uncertainty-r(min)))
gen ${DEPVAR}_SRp1 = exp(l${DEPVAR} - _b[uncertainty]*(uncertainty-r(p1)))
gen ${DEPVAR}_LRp1 = exp(l${DEPVAR} - _b[uncertainty]/(1-_b[l.l${DEPVAR}])*(uncertainty-r(p1)))
gen ${DEPVAR}_SRp10 = exp(l${DEPVAR} - _b[uncertainty]*(uncertainty-r(p10)))
gen ${DEPVAR}_LRp10 = exp(l${DEPVAR} - _b[uncertainty]/(1-_b[l.l${DEPVAR}])*(uncertainty-r(p10)))
gen ${DEPVAR}_SRp25 = exp(l${DEPVAR} - _b[uncertainty]*(uncertainty-r(p25)))
gen ${DEPVAR}_LRp25 = exp(l${DEPVAR} - _b[uncertainty]/(1-_b[l.l${DEPVAR}])*(uncertainty-r(p25)))
gen ${DEPVAR}_SRp50 = exp(l${DEPVAR} - _b[uncertainty]*(uncertainty-r(p50)))
gen ${DEPVAR}_LRp50 = exp(l${DEPVAR} - _b[uncertainty]/(1-_b[l.l${DEPVAR}])*(uncertainty-r(p50)))
sum uncertainty if civilservant==1, d /* Median Uncertainty */
gen ${DEPVAR}_SRcs = exp(l${DEPVAR} - _b[uncertainty]*(uncertainty-r(p50)))
gen ${DEPVAR}_LRcs = exp(l${DEPVAR} - _b[uncertainty]/(1-_b[l.l${DEPVAR}])*(uncertainty-r(p50)))
/* Variables for PCT reduction table */
gen pctred_SRmin = -100*(${DEPVAR}_SRmin - ${DEPVAR})/${DEPVAR} if e(sample)
gen pctred_LRmin = -100*(${DEPVAR}_LRmin - ${DEPVAR})/${DEPVAR} if e(sample)
gen pctred_SRp1 = -100*(${DEPVAR}_SRp1 - ${DEPVAR})/${DEPVAR} if e(sample)
gen pctred_LRp1 = -100*(${DEPVAR}_LRp1 - ${DEPVAR})/${DEPVAR} if e(sample)
gen pctred_SRp10 = -100*(${DEPVAR}_SRp10 - ${DEPVAR})/${DEPVAR} if e(sample)
gen pctred_LRp10 = -100*(${DEPVAR}_LRp10 - ${DEPVAR})/${DEPVAR} if e(sample)
gen pctred_SRp25 = -100*(${DEPVAR}_SRp25 - ${DEPVAR})/${DEPVAR} if e(sample)
gen pctred_LRp25 = -100*(${DEPVAR}_LRp25 - ${DEPVAR})/${DEPVAR} if e(sample)
gen pctred_SRp50 = -100*(${DEPVAR}_SRp50 - ${DEPVAR})/${DEPVAR} if e(sample)
gen pctred_LRp50 = -100*(${DEPVAR}_LRp50 - ${DEPVAR})/${DEPVAR} if e(sample)
gen pctred_SRcs = -100*(${DEPVAR}_SRcs - ${DEPVAR})/${DEPVAR} if e(sample)
gen pctred_LRcs = -100*(${DEPVAR}_LRcs - ${DEPVAR})/${DEPVAR} if e(sample)
/* Variables for PCT reduction table loop */
gen red1=pctred_SRmin 
gen red2=pctred_LRmin 
gen red3=pctred_SRp1
gen red4=pctred_LRp1 
gen red5=pctred_SRp10
gen red6=pctred_LRp10 
gen red7=pctred_SRp25
gen red8=pctred_LRp25
gen red9=pctred_SRp50
gen red10=pctred_LRp50 
gen red11=pctred_SRcs
gen red12=pctred_LRcs
gen occupation2=.
replace occupation2=2 if selfemployed==1
replace occupation2=3 if whitecollar==1
replace occupation2=4 if bluecollar==1
replace occupation2=5 if civilservant==1
/* Matrix definition */
# d;
mat reduction= (.,.,.,.,. \ .,.,.,.,. \ .,.,.,.,. \ .,.,.,.,. \ .,.,.,.,. \ .,.,.,.,.  \ 
.,.,.,.,. \ .,.,.,.,. \ .,.,.,.,. \ .,.,.,.,. \ .,.,.,.,. \ .,.,.,.,. ); 
matrix colnames reduction  = All Self WC BC CS;
matrix rownames reduction =
pctred_SRmin  pctred_LRmin pctred_SRp1 pctred_LRp1 pctred_SRp10  pctred_LRp10 
pctred_SRp25 pctred_LRp25 pctred_SRp50 pctred_LRp50 pctred_SRcs pctred_LRcs ;
#d cr

forval x=1/12 {
	quietly: sum red`x' [aw=phrf] if e(sample)
	quietly: mat reduction[`x',1 ]=r(mean)
}   

forval y=2/5 {
forval x=1/12 {
	quietly: sum red`x' [aw=phrf] if e(sample) & occupation2==`y'
	quietly: mat reduction[`x',`y']=r(mean)
}   
}
outtable using "${TABLES}pctred", mat(reduction) replace center f(%9.2f) nobox  caption("Percentage Reduction for Different Occupations") 
drop red1-red12 occupation2
if ${GRAPHS}==1 {
gen quantiles = ${DEPVAR}
sort quantiles
gen long counts=sum(quantiles<.)
gen fraction=counts/counts[_N]
gen lines=quantiles[1] + counts* ((quantiles[counts[_N]]-quantiles[1])/counts[_N])
gen SRquantiles = ${DEPVAR}_SRmin
sort SRquantiles
gen long SRcounts=sum(SRquantiles<.)
gen SRfraction=SRcounts/SRcounts[_N]
gen LRquantiles = ${DEPVAR}_LRmin
sort LRquantiles
gen long LRcounts=sum(LRquantiles<.)
gen LRfraction=LRcounts/LRcounts[_N]
# d;
twoway (scatter fraction LRquantiles if year==2011,
	sort				         
	m(th) mc(orange) msize(small)     
	)							 
	(scatter fraction SRquantiles  if year==2011,  
	sort				         
	m(plus) mc(purple)	msize(small)		         
	)				        	 
	(scatter fraction quantiles  if year==2011, 
	sort				         
	ytitle(Fraction of the Hours Distribution)
	ylabel(0(.25)1, grid)	    
	xtitle(Hours of Work)	
	m(smcircle_hollow) mc(black) 
	legend(position(12) col(3) label(3 "Actual") label(2 "Short-Run") label(1 "Long-Run")) 
);
#d cr
graph export "${FIGURES}simulation.eps", replace

drop ${DEPVAR}_SRmin-LRfraction
sort pid year
}
/***********************************************************/	
/* Tables: Compare Different Occupations & ISCOs           */
/***********************************************************/
local options ${MAINOPT}
local instruments ${MAINIV} 
local occupations
local net_occupations
local net_regressions_isco
local gross_regressions_isco

foreach occupation of varlist selfemployed whitecollar bluecollar civilservant isco_1 - isco_5 isco_7 - isco_9 {
	replace lab_inc=pglabgro
	replace wage=lwhr_${DEPVAR}
	replace income=luninc
	replace uncertainty=sd${l}_whr_${DEPVAR}_BU /* Use back-ups here and normalise sample-specific */
	replace expunemployed=expunemployed_BU
		
	# d;
	eststo gross_`occupation': xi: xtabond2 l${DEPVAR} l.l${DEPVAR} uncertainty expunemployed wage 
	${CONTROLS} if `occupation'==1 & olssample==1, `instruments' `options';
	sum uncertainty [aw=phrf] if e(sample);
	replace uncertainty=uncertainty/r(sd);
	sum expunemployed [aw=phrf] if e(sample);
	replace expunemployed=expunemployed/r(sd);
	eststo gross_`occupation': xi: xtabond2 l${DEPVAR} l.l${DEPVAR} uncertainty expunemployed wage 
	${CONTROLS} if `occupation'==1 & olssample==1, `instruments' `options';	
	
	mat b =  e(gmmlaglimits);
	estadd scalar lagstart = b[1,1];
	estadd scalar lagend = b[2,1];
	estadd scalar AR1inFD = e(ar1p);
	estadd scalar AR2inFD = e(ar2p);
	estadd scalar AR3inFD = e(ar3p);
	estadd scalar Sargan =  e(sarganp);
	estadd scalar Hansen =  e(hansenp);
	mat a =  e(diffsargan);
	estadd scalar Hansentestexclgroup =  a[4,1];
	estadd scalar DifferenceHansen =  a[5,1];
	estadd ysumm, mean;
							
	est resto gross_`occupation';				
	
	if "`occupation'"== "dependent" | "`occupation'"==  "selfemployed" |"`occupation'"=="whitecollar" | 
	   "`occupation'"=="bluecollar" |"`occupation'"=="civilservant" 
	{; 
			local occupations `occupations'  gross_`occupation'; 
	};
	if "`occupation'"== "isco_1" | "`occupation'"== "isco_2" | "`occupation'"== "isco_3" | "`occupation'"== "isco_4" |
	 "`occupation'"== "isco_5" |"`occupation'"== "isco_6" |"`occupation'"== "isco_7" |
	 "`occupation'"== "isco_8" |"`occupation'"== "isco_9" 
	 {; 
		local gross_regressions_isco `gross_regressions_isco'  gross_`occupation'; 
	};
			
	#d cr
									
	if ${NETWAGES}==1{
		replace lab_inc=pglabnet
		replace wage=lnet_wage_${DEPVAR}
		replace income=lvirtual_income_${DEPVAR}
		replace uncertainty=sd${l}_net_wage_${DEPVAR}_BU	
		replace expunemployed=expunemployed_BU
		
		# d;
		di "net `condition' `gecondition' ${DEPVAR} `occupation'  OS`optionset' IV`instrumentset'";
		eststo net_`occupation': xi: xtabond2 l${DEPVAR} l.l${DEPVAR} uncertainty expunemployed wage 
		${CONTROLS} if   `occupation'==1 & olssample==1, `instruments' `options';
		sum uncertainty [aw=phrf] if e(sample);
		replace uncertainty=uncertainty/r(sd);
		sum expunemployed [aw=phrf] if e(sample);
		replace expunemployed=expunemployed/r(sd);
		di "net `condition' `gecondition' ${DEPVAR} `occupation'  OS`optionset' IV`instrumentset'";
		eststo net_`occupation': xi: xtabond2 l${DEPVAR} l.l${DEPVAR} uncertainty expunemployed wage  
		${CONTROLS} if   `occupation'==1 & olssample==1, `instruments' `options';
		
		mat b =  e(gmmlaglimits);
		estadd scalar lagstart = b[1,1];
		estadd scalar lagend = b[2,1];
		estadd scalar AR1inFD = e(ar1p);
		estadd scalar AR2inFD = e(ar2p);
		estadd scalar AR3inFD = e(ar3p);
		estadd scalar Sargan =  e(sarganp);
		estadd scalar Hansen =  e(hansenp);
		mat a =  e(diffsargan);
		estadd scalar Hansentestexclgroup =  a[4,1];
		estadd scalar DifferenceHansen =  a[5,1];
		estadd ysumm, mean;
		
		est resto net_`occupation';
		if "`occupation'"== "dependent" | "`occupation'"==  "selfemployed" |"`occupation'"=="whitecollar" | 
		"`occupation'"=="bluecollar" |"`occupation'"=="civilservant" 
		{; 
			local net_occupations `net_occupations'  net_`occupation'; 
		};
		if "`occupation'"== "isco_1" | "`occupation'"== "isco_2" | "`occupation'"== "isco_3" | "`occupation'"== "isco_4" |
		"`occupation'"== "isco_5" |"`occupation'"== "isco_6" |"`occupation'"== "isco_7" |
		"`occupation'"== "isco_8" |"`occupation'"== "isco_9" 
		{; 
			local net_regressions_isco `net_regressions_isco'  net_`occupation'; 
		};												
		#d cr						
	}/* End of Net wages */
}/* End of Occupations */
		
esttab `occupations' using "${TABLES}\occupations_gross.tex",  label se(3) b(3) replace mtitles(`occupations') sfmt(3) scalars(${TESTS}) star(* 0.10 ** 0.05 *** 0.01) 
local occupations	
esttab `gross_regressions_isco' using "${TABLES}\isco_gross.tex",  label se(3) b(3) replace mtitles(`gross_regressions_isco') sfmt(3) scalars(${TESTS}) star(* 0.10 ** 0.05 *** 0.01) 
local gross_regressions_isco

if ${NETWAGES}==1{
	esttab `net_regressions_isco' using "${TABLES}\isco_net.tex",  label se(3) b(3) replace mtitles(`net_regressions_isco') sfmt(3) scalars(${TESTS}) star(* 0.10 ** 0.05 *** 0.01) 
	local net_regressions_isco
	esttab `net_occupations' using "${TABLES}\occupations_net.tex",  label se(3) b(3) replace mtitles(`net_occupations') sfmt(3) scalars(${TESTS}) star(* 0.10 ** 0.05 *** 0.01) 
	local net_occupations
}			

/***********************************************************/
/*              Table: Alternative Dependent variables                 */
/***********************************************************/
local options ${MAINOPT}
local instruments ${MAINIV} 
local occupations
local net_regressions_isco
local gross_regressions_isco

foreach alt_y of varlist $ALTDEPVARS {
		replace lab_inc=pglabgro
		replace wage=lwhr_`alt_y'
		replace income=luninc
		replace uncertainty=sd${l}_whr_`alt_y'_BU
		replace expunemployed=expunemployed_BU

		# d;
		xi: xtabond2 l`alt_y' l.l`alt_y' uncertainty expunemployed wage 
		${CONTROLS} if ${MAINOCC} ==1 & olssample==1, `instruments' `options';
		if "`alt_y'"== "plb0241" {;
			xi: xtabond2 l`alt_y'  uncertainty expunemployed wage 
			${CONTROLS} if ${MAINOCC} ==1 & olssample==1, iv(${CONTROLS} uncertainty expunemployed l.lab_inc,)`options';
		};	
		sum uncertainty [aw=phrf]  if e(sample);
		replace uncertainty=uncertainty/r(sd);
		sum expunemployed [aw=phrf]  if e(sample);
		replace expunemployed=expunemployed/r(sd);		
		eststo gross_`alt_y': xi: xtabond2 l`alt_y' l.l`alt_y' uncertainty expunemployed wage 
		${CONTROLS} if ${MAINOCC} ==1 & olssample==1, `instruments' `options';
		if "`alt_y'"== "plb0241" {;
			eststo gross_`alt_y': xi: xtabond2 l`alt_y'  uncertainty expunemployed wage 
			${CONTROLS} if ${MAINOCC} ==1 & olssample==1, iv(${CONTROLS} uncertainty expunemployed l.lab_inc,)`options';
		};	
		mat b =  e(gmmlaglimits);
		estadd scalar lagstart = b[1,1];
		estadd scalar lagend = b[2,1];
		estadd scalar AR1inFD = e(ar1p);
		estadd scalar AR2inFD = e(ar2p);
		estadd scalar AR3inFD = e(ar3p);
		estadd scalar Sargan =  e(sarganp);
		estadd scalar Hansen =  e(hansenp);
		mat a =  e(diffsargan);
		estadd scalar Hansentestexclgroup =  a[4,1];
		estadd scalar DifferenceHansen =  a[5,1];
		estadd ysumm, mean;
								
		est resto gross_`alt_y';				
		#d cr	

		if ${NETWAGES}==1{
			replace lab_inc=pglabnet
			replace wage=lnet_wage_`alt_y'
			replace income=lvirtual_income_`alt_y'
			replace uncertainty=sd${l}_net_wage_`alt_y'	

			# d;
			eststo net_`alt_y': xi: xtabond2 l`alt_y' l.l`alt_y' uncertainty expunemployed wage 
			${CONTROLS} if   ${MAINOCC}==1, `instruments' `options';
			if "`alt_y'"== "plb0241" {;
				eststo net_`alt_y': xi: xtabond2 l`alt_y' uncertainty expunemployed wage 
				${CONTROLS} if ${MAINOCC} ==1, gmm(income l.lab_inc, collapse) iv(${CONTROLS})`options';
			};									
			mat b =  e(gmmlaglimits);
			estadd scalar lagstart = b[1,1];
			estadd scalar lagend = b[2,1];
			estadd scalar AR1inFD = e(ar1p);
			estadd scalar AR2inFD = e(ar2p);
			estadd scalar AR3inFD = e(ar3p);
			estadd scalar Sargan =  e(sarganp);
			estadd scalar Hansen =  e(hansenp);
			mat a =  e(diffsargan);
			estadd scalar Hansentestexclgroup =  a[4,1];
			estadd scalar DifferenceHansen =  a[5,1];
			estadd ysumm, mean;
			
			est resto net_`alt_y';
			local alterndepvars `alterndepvars' net_`alt_y';
			#d cr
	}/* End of Net wages */
}/* Alternative Depvars */
if ${NETWAGES}==1{		
	esttab `alterndepvars' using "${TABLES}\alterndepvars.tex",  label se replace mtitles(`alterndepvars') sfmt(3) scalars(${TESTS}) star(* 0.10 ** 0.05 *** 0.01) 
}
local alterndepvars	

/***********************************************************/
/*              Table: Alternative Risk Measures           */
/***********************************************************/			

	if ${NETWAGES}==1{
		local options ${MAINOPT}
		local instruments ${MAINIV} 
		local alternrisks

		global ALTRISK1 "sdlf_net_wage_${DEPVAR}"
		global ALTRISK2 "sdl5_net_wage_${DEPVAR}"
		global ALTRISK3 "sdl_wod_net_wage_${DEPVAR}"
		global ALTRISK4 "sdlcont_net_wage_${DEPVAR}"
		global ALTRISK5 "1"
		global ALTRISK6 "sdl_net_wage_${DEPVAR}"
		global RISKCONTROLS1 " "
		global RISKCONTROLS2 " "
		global RISKCONTROLS3 " "
		global RISKCONTROLS4 " "
		global RISKCONTROLS5 "i.someworries i.bigworries"
		global RISKCONTROLS6 "i.someworries i.bigworries"

		forval risktype=1/6  {
			replace lab_inc=pglabnet
			replace wage=lnet_wage_${DEPVAR}
			replace income=lvirtual_income_${DEPVAR}
			replace uncertainty=${ALTRISK`risktype'}
			replace expunemployed=expunemployed_BU
			# d;
			eststo net_rt`risktype': xi: xtabond2 l${DEPVAR} l.l${DEPVAR} uncertainty expunemployed wage 
			${CONTROLS} ${RISKCONTROLS`risktype'} if ${MAINOCC} ==1 & olssample==1 , `instruments' `options';
			sum uncertainty [aw=phrf] if e(sample);
			replace uncertainty=uncertainty/r(sd);
			if "`risktype'"=="5" {;
				replace uncertainty=${ALTRISK`risktype'};
			};	
			sum expunemployed [aw=phrf] if e(sample);
			replace expunemployed=expunemployed/r(sd);
			eststo net_rt`risktype': xi: xtabond2 l${DEPVAR} l.l${DEPVAR} uncertainty expunemployed wage 
			${CONTROLS} ${RISKCONTROLS`risktype'} if ${MAINOCC} ==1 & olssample==1, `instruments' `options';
			estadd scalar AR1inFD = e(ar1p);
			estadd scalar AR2inFD = e(ar2p);
			estadd scalar Hansen =  e(hansenp);	
			est resto net_rt`risktype';				
			local alternrisks `alternrisks' net_rt`risktype';  
			#d cr				
		}		
	
	        replace lab_inc=pglabnet
			replace wage=lnet_wage_${DEPVAR}
			replace income=lvirtual_income_${DEPVAR}
			replace uncertainty=sdl_net_wage_${DEPVAR}
			replace expunemployed=expunemployed_BU
			# d;
			eststo net_rtfamrisk: xi: xtabond2 l${DEPVAR} l.l${DEPVAR} uncertainty expunemployed wage sdl_other_inc_net 
			${CONTROLS} ${RISKCONTROLS`risktype'} if ${MAINOCC} ==1 & olssample==1 , `instruments' `options';
			sum uncertainty [aw=phrf] if e(sample);
			replace uncertainty=uncertainty/r(sd);
			sum sdl_other_inc_net [aw=phrf] if e(sample);
			replace  sdl_other_inc_net=sdl_other_inc_net/r(sd);
			sum expunemployed [aw=phrf] if e(sample);
			replace expunemployed=expunemployed/r(sd);
			eststo net_rtfamrisk: xi: xtabond2 l${DEPVAR} l.l${DEPVAR} uncertainty expunemployed wage sdl_other_inc_net 
			${CONTROLS} ${RISKCONTROLS`risktype'} if ${MAINOCC} ==1 & olssample==1, `instruments' `options';
			estadd scalar AR1inFD = e(ar1p);
			estadd scalar AR2inFD = e(ar2p);
			estadd scalar Hansen =  e(hansenp);	
			est resto net_rtfamrisk;				
			local alternrisks `alternrisks' net_rtfamrisk;  
			#d cr				
	
		
	esttab `alternrisks' using "${TABLES}\alternrisks_net.tex",  label se(3) b(3) replace mtitles(fwd 5years wod cont worries  worries_sdl famrisk) sfmt(3) scalars(${TESTS}) star(* 0.10 ** 0.05 *** 0.01) 
	local alternrisks	
	}
} /* End of ESTIMATION */ 			

if ${GRAPHS}==1 {
		/* For each occupation over `dimension' */	
		use "${DATA_PATH}estimation", clear 
		keep if age>=25 & age<=55
		gen agegroup=.
		forvalues gruppe= 25(3)55{
			replace agegroup = `gruppe' if age<=`gruppe' & agegroup==. 
		}
		replace age=agegroup
		
		gen n_age_wage=.
		gen n_age_expu=.
		gen n_age_wagerate=.
		gen n_age_hours=.
		cap drop wage
		gen wage=.
		
		if ${NETWAGES}==1{
			replace uncertainty=sd${l}_net_wage_${DEPVAR}_BU
			replace wage=net_wage_paid_hours
		}
		else {
			replace uncertainty=sd${l}_whr_${DEPVAR}_BU
			replace wage=whr_paid_hours
		}
		levelsof occupation, local(occs)
		foreach occ in `occs'{
		
			forvalues i=25/55{
				count if uncertainty!=. & age==`i'  & occupation==`occ'
				replace n_age_wage=r(N) if age==`i' & occupation==`occ'
				count if expunemployed_BU!=. & age==`i'  & occupation==`occ'
				replace n_age_expu=r(N) if age==`i' & occupation==`occ'
				count if wage!=. & age==`i'  & occupation==`occ'
				replace n_age_wagerate=r(N) if age==`i' & occupation==`occ'
				count if paid_hours!=. & age==`i'  & occupation==`occ'
				replace n_age_hours=r(N) if age==`i' & occupation==`occ'
			}
		}
		replace uncertainty = . if n_age_wage<=15
		replace expunemployed_BU = . if n_age_expu<=15
		replace wage=. if n_age_wagerate<=15
		replace paid_hours =. if n_age_hours<=15
		
		
		collapse (mean) uncertainty expunemployed_BU wage paid_hours [aw=phrf], by(age occupation) 
			label var expunemployed_BU "Unemployment Probability"
			label var uncertainty "Wage Risk"
			label var wage "Net Hourly Wage"
			label var paid_hours "Weekly Hours Worked"
			label var age "Age"
		# d;
		twoway (line uncertainty age if occupation==1, lpattern(solid) lcolor(teal) lwidth(thick)) 
		   (line uncertainty age if occupation==2, lpattern(dash) lcolor(dkgreen) lwidth(thick)) 
		 (line uncertainty age if occupation==3, lpattern(shortdash) lcolor(purple) lwidth(thick)) 
		 (line uncertainty age if occupation==4, lpattern(dash_dot) lcolor(orange) lwidth(thick)), 
		legend( label(1 "Blue Collar") label(2 "White Collar") label(3 "Civil Servants") label(4 "Self-employed"));
		#d cr
		graph export "${FIGURES}wagerisk.eps", replace 

		# d;
		twoway (line expunemployed_BU age if occupation==1, lpattern(solid) lcolor(teal) lwidth(thick)) 
		   (line expunemployed_BU age if occupation==2, lpattern(dash) lcolor(dkgreen) lwidth(thick)) 
		 (line expunemployed_BU age if occupation==3, lpattern(shortdash) lcolor(purple) lwidth(thick)) 
		 (line expunemployed_BU age if occupation==4, lpattern(dash_dot) lcolor(orange) lwidth(thick)), 
		legend( label(1 "Blue Collar") label(2 "White Collar") label(3 "Civil Servants") label(4 "Self-employed"));
		#d cr
		graph export "${FIGURES}expunemployed.eps", replace 
		
		# d;
		twoway (line wage age if occupation==1, lpattern(solid) lcolor(teal) lwidth(thick)) 
		   (line wage age if occupation==2, lpattern(dash) lcolor(dkgreen)lwidth(thick)) 
		 (line wage age if occupation==3, lpattern(shortdash) lcolor(purple) lwidth(thick)) 
		 (line wage age if occupation==4, lpattern(dash_dot) lcolor(orange) lwidth(thick)),
		legend( label(1 "Blue Collar") label(2 "White Collar") label(3 "Civil Servants") label(4 "Self-employed"));
		#d cr
		graph export "${FIGURES}wage.eps", replace 		
		
				# d;
		twoway (line paid_hours age if occupation==1, lpattern(solid) lcolor(teal) lwidth(thick)) 
		   (line paid_hours age if occupation==2,  lpattern(dash) lcolor(dkgreen) lwidth(thick)) 
		 (line paid_hours age if occupation==3,  lpattern(shortdash) lcolor(purple) lwidth(thick)) 
		 (line paid_hours age if occupation==4,  lpattern(dash_dot) lcolor(orange) lwidth(thick)), 
		legend( label(1 "Blue Collar") label(2 "White Collar") label(3 "Civil Servants") label(4 "Self-employed"));
		#d cr
		graph export "${FIGURES}hours.eps", replace
		
		
		
}/* End of Graphs */
 
cap log close	
